﻿//Copyright (c) Victor Hurdugaci
//http://victorhurdugaci.com
//This code is licensed under the Non-Profit Open Software License version 3.0
//Full license text: http://www.opensource.org/licenses/NOSL3.0.html

using System;
using System.Text;
using System.Runtime.InteropServices;

namespace TaskSwitcher
{
    /// <summary>
    /// Represents the information about a single window
    /// </summary>
    sealed class WindowInfo
    {
        #region user32.dll imports

        [DllImport("user32.dll")]
        private static extern int GetWindowText(IntPtr hWnd, StringBuilder lpString, int nMaxCount);

        [DllImport("user32.dll")]
        private static extern int GetWindowTextLength(IntPtr hWnd);

        #endregion

        /// <summary>
        /// Creates a new instance of WindowInfo
        /// </summary>
        /// <param name="hWnd">The handle of the window which is represented by this instance</param>
        public WindowInfo(IntPtr hWnd)
        {
            this.HWnd = hWnd;
            this.Title = GetWindowTitle(this.HWnd);
        }

        /// <summary>
        /// Gets the window title
        /// </summary>
        public string Title { get; private set; }

        /// <summary>
        /// Gets the window handle
        /// </summary>
        public IntPtr HWnd { get; private set; }

        /// <summary>
        /// Gets or sets the associated DWM thumbnail
        /// </summary>
        public IntPtr Thumbnail { get; set; }

        private string GetWindowTitle(IntPtr hWnd)
        {
            int length = GetWindowTextLength(hWnd);

            StringBuilder title = new StringBuilder(length + 1);
            GetWindowText(hWnd, title, title.Capacity);

            return title.ToString();
        }
    }
}
